@@ -8,7 +8,7 @@ spi <- function(x, y,...) UseMethod('spi')
 spi <-
 function(data, scale, kernel=list(type='rectangular',shift=0),
 	distribution='Gamma', fit='ub-pwm', na.rm=FALSE,
-	ref.start=NULL, ref.end=NULL, x=FALSE, ...) {
+	ref.start=NULL, ref.end=NULL, x=FALSE, params=NULL, ...) {
 	return(spei(data, scale, kernel, distribution, fit, na.rm,
-	ref.start, ref.end, x))
+	ref.start, ref.end, x, params))
 }
